@@ -1,6 +1,7 @@
 import time
 import pytest
 from pathlib import Path
+import os
 from indico.client import IndicoClient
 from indico.queries.datasets import (
     GetDataset,
@@ -23,16 +24,16 @@ def test_create_dataset(indico):
         )
     )
 
-    assert type(response) == Dataset
+    assert isinstance(response, Dataset)
     assert response.status == "COMPLETE"
-    assert type(response.id) == int
+    assert isinstance(response.id, int)
 
 
 def test_get_datasets(indico, airlines_dataset):
     client = IndicoClient()
     dataset = client.call(GetDataset(id=airlines_dataset.id))
 
-    assert type(dataset) == Dataset
+    assert isinstance(dataset, Dataset)
     assert dataset.id == airlines_dataset.id
 
 
@@ -47,7 +48,7 @@ def test_get_dataset_file_status(indico, airlines_dataset):
     client = IndicoClient()
     dataset = client.call(GetDatasetFileStatus(id=airlines_dataset.id))
 
-    assert type(dataset) == Dataset
+    assert isinstance(dataset, Dataset)
     assert dataset.id == airlines_dataset.id
     assert len(dataset.files) > 0
     assert dataset.files[0].status != None
@@ -57,7 +58,7 @@ def test_list_datasets(indico, airlines_dataset):
     client = IndicoClient()
     datasets = client.call(ListDatasets(limit=1))
 
-    assert type(datasets) == list
+    assert isinstance(datasets, list)
     assert len(datasets) == 1
     assert type(datasets[0]) == Dataset
 
@@ -73,6 +74,47 @@ def test_images(indico):
             from_local_images=True,
         )
     )
-    assert type(response) == Dataset
+    assert isinstance(response, Dataset)
     assert response.status == "COMPLETE"
-    assert type(response.id) == int
+    assert isinstance(response.id, int)
+
+
+def test_images_batch(indico):
+    client = IndicoClient()
+
+    dataset_filepath = str(Path(__file__).parents[1]) + "/data/dog_vs_cats_small.csv"
+    response = client.call(
+        CreateDataset(
+            name=f"image-dataset-test-{int(time.time())}",
+            files=dataset_filepath,
+            from_local_images=True,
+            batch_size=10,
+        )
+    )
+    assert isinstance(response, Dataset)
+    assert response.status == "COMPLETE"
+    assert isinstance(response.id, int)
+
+
+def test_upload_pdf_dataset_batch(indico):
+    client = IndicoClient()
+    file_names = ["mock.pdf", "mock_2.pdf", "mock_3.pdf"]
+    parent_path = str(Path(__file__).parent.parent / "data")
+    dataset_filepaths = [
+        os.path.join(parent_path, file_name) for file_name in file_names
+    ]
+    dataset = client.call(
+        CreateDataset(
+            name=f"pdf-dataset-test-{int(time.time())}",
+            files=dataset_filepaths,
+            batch_size=1,
+        )
+    )
+    assert isinstance(dataset, Dataset)
+    assert dataset.status == "COMPLETE"
+    assert isinstance(dataset.id, int)
+    assert dataset.datacolumns[0].name == "text"
+    response = client.call(GetDatasetFileStatus(id=dataset.id))
+    for datafile in response.files:
+        assert datafile.status == "PROCESSED"
+        assert datafile.file_type == "pdf"
